@@ -92,6 +92,9 @@ def gen_market_data(credentials, tckrs, settings, api, fullSend, fixedDate='', f
                     modeling=False):
     # check if market is open
     clock = get_clock(fixedDate=fixedDate, modeling=modeling)
+    print(credentials)
+    paidSubscription = credentials['endpoint']['premium_data']
+
     if verbose:
         print('PRINTING CLOCK')
 
@@ -195,8 +198,8 @@ def gen_market_data(credentials, tckrs, settings, api, fullSend, fixedDate='', f
             timeOffset = endDate - relativedelta(minutes=15)
             # print('offset compare', nowish, endDate, (nowish) <= endDate)
             if not modeling:
-                if key == 'DAILY MARKET DATA':
-                    if clock['isOpen']:
+                if key == 'DAILY MARKET DATA' and paidSubscription == False:
+                    if clock['isOpen'] :
                         endDate = clock['nowUTC'] - relativedelta(minutes=15)
                         if nowish <= startDate:
                             startDate = startDate - relativedelta(minutes=15)
@@ -323,10 +326,12 @@ def get_table(dataset=[], raw=False):
             # print(rawData)
             output["marketData"][dset]['RAW DATA'] = rawData
     fileName = "data/COMPANY INFO DATA.json"
-    coInfo = dbmsIO.extract_json(fileName=fileName)
-    coInfo = pd.DataFrame.from_dict(coInfo['COMPANY INFO'])
-    output["Company Info"] = coInfo
-    # print(coInfo)
+    #print(os.stat(ROOT_DIR + r'/' +fileName).st_size)
+    if os.stat(ROOT_DIR + r'/' +fileName).st_size>5:
+        coInfo = dbmsIO.extract_json(fileName=fileName)
+        coInfo = pd.DataFrame.from_dict(coInfo['COMPANY INFO'])
+        output["Company Info"] = coInfo
+
     return output
 
 
@@ -337,5 +342,7 @@ def get_datasets():
 def get_tckrs():
     return extract_library.get_tckrs()
 
+def obj_to_df(obj):
+    return transform_library.object_to_df(obj)
 
 ROOT_DIR = os.path.dirname(os.path.abspath(__file__))
